@@ -1,11 +1,16 @@
+#This requires revision it has more parameters that extends beyond the limit of 95 characters line width
 regr <-
-function(x,y,sav="NULL",spec.type="wavelet transformed",reg="svm",per="TRUE",per.n=0.3,num,model.name="test",drv=1,bandwidth=21,validation="CV",filte="haar",level=3,distribution="gaussian",n.trees=1000,shrinkage=0.01,kerne="radial"){
-	
+function(x,y,sw="NL",sp="wt",r="svm",p="T",pn=0.3,n,md="test",drv=1,bandwidth=21,val="CV",ft="h",lv=3,dis="g",nt=1000,s=0.01,k="ra"){
+#Set the two global variables: distribution AND validation to NL
+distribution<-validation<-NULL
+
+#Set other global variables: 
+box.cox.powers<-bc<-MSEP<-gbm.fit<-gbm.perf<-NULL
 # Check on function body:
 
 a<-c(rownames(x),rownames(y));
 if(nrow(x)==nrow(y) & length(unique(a))!=nrow(y)){
-	b<-a[which(duplicated(a)=="TRUE")];
+	b<-a[which(duplicated(a)=="T")];
 	x<-x[b,];
 	y<-y[b,];
 	rm(b);
@@ -37,30 +42,30 @@ if(as.numeric(colnames(x)[1])>as.numeric(colnames(x)[2])){
 	}
 if(class(y)!="data.frame" & class(y)!="matrix"){stop("Invalid argument: 'y' must be of class 'data.frame' or 'matrix'.")};
 if(class(y)=="matrix"){y<-as.data.frame(y)};
-if(sav=="NULL"){sav<-getwd()};
-if(spec.type!="raw" & spec.type!="derivative" & spec.type!="continuum removed" & spec.type!="wavelet transformed"){stop("Invalid argument: 'spec.type' has to be either 'raw', 'derivative', 'continuum removed' or 'wavelet transformed'.")};
-if(is.na(match(reg,c("pls","brt","svm")))){stop("Invalid argument: 'reg' has to be either 'pls', 'brt' or 'svm'.")};
-if(reg=="brt" & nrow(x)<70){stop("Invalid argument: when 'reg' is equl to 'brt' the number of samples has to be more than 70.")};
-if(class(per)!="character"){stop("Invalid argument: 'per' has to be of class 'character'.")}
-if(is.na(match(per,c("TRUE","FALSE")))){stop("Invalid argument: 'per' has to be either 'TRUE' or 'FALSE'.")}
-if(class(per.n)!="numeric"){stop("Invalid argument: 'per' has to be of class 'numeric'.")};
-if(per.n<0 | per.n>1){stop("Invalid argument: 'per' has to be between 0 and 1.")}
-if(per=="TRUE"){
+if(sw=="NL"){sw<-getwd()};
+if(sp!="raw" & sp!="derivative" & sp!="continuum removed" & sp!="wt"){stop("Invalid argument: 'sp' has to be either 'raw', 'derivative', 'continuum removed' or 'wt'.")};
+if(is.na(match(r,c("pls","brt","svm")))){stop("Invalid argument: 'r' has to be either 'pls', 'brt' or 'svm'.")};
+if(r=="brt" & nrow(x)<70){stop("Invalid argument: when 'r' is equl to 'brt' the number of samples has to be more than 70.")};
+if(class(p)!="character"){stop("Invalid argument: 'p' has to be of class 'character'.")}
+if(is.na(match(p,c("T","FALSE")))){stop("Invalid argument: 'p' has to be either 'T' or 'FALSE'.")}
+if(class(pn)!="numeric"){stop("Invalid argument: 'p' has to be of class 'numeric'.")};
+if(pn<0 | pn>1){stop("Invalid argument: 'p' has to be between 0 and 1.")}
+if(p=="T"){
 	n<-c();
 	for(i in 1:ncol(y)){
-	n[i]<-round(per.n*length(na.omit(y[,i])),0);
+	n[i]<-round(pn*length(na.omit(y[,i])),0);
 		}
 }
-if(per=="FALSE"){
-	if(exists("num")=="FALSE"){stop("Invalid argument: object 'num' not found.")}
-	if(class(as.integer(num))!="integer"){stop("Invalid argument: 'num' has to be of class 'integer'.")};
-	if(num<1 | num>=nrow(x)){stop("Invalid argument: 'num' has to be between 1 and the number of samples minus one.")};
+if(p=="FALSE"){
+	if(exists("n")=="FALSE"){stop("Invalid argument: object 'n' not found.")}
+	if(class(as.integer(n))!="integer"){stop("Invalid argument: 'n' has to be of class 'integer'.")};
+	if(n<1 | n>=nrow(x)){stop("Invalid argument: 'n' has to be between 1 and the number of samples minus one.")};
 	n<-c();
 	for(i in 1:ncol(y)){
-	n[i]<-num;	
+	n[i]<-n;	
 		}
 }
-if(class(model.name)!="character"){stop("Invalid argument: 'model.name' has to be of class 'character'.")}
+if(class(md)!="character"){stop("Invalid argument: 'md' has to be of class 'character'.")}
 
 # Check additional objects for changing other functions (locpoly, pls, brt, svm):
 
@@ -75,41 +80,41 @@ if(bandwidth<1 | bandwidth > 30){stop("Invalid argument: 'bandwidth' has to be b
 if(class(validation)!="character"){stop("Invalid argument: 'validation' has to be of class 'character'.")}
 if(validation!="CV" & validation!="none" & validation!="LOO"){stop("Invalid argument: 'validation' has to be either 'none', 'CV' or 'LOO'.")}
 # dwt function:
-if(class(filte)!="character"){stop("Invalid argument: 'filte' has to be of class 'character'.")}
-if(filte!="haar" &filte!="d4" &filte!="d6" &filte!="d8" &filte!="d10" &filte!="d12" &filte!="d14" &filte!="d16" &filte!="d18" &filte!="d20" &filte!="la8" &filte!="la10" &filte!="la12" &filte!="la14" &filte!="la16" &filte!="la18" &filte!="la20" &filte!="bl14" &filte!="bl18" &filte!="bl20" &filte!="c6" &filte!="c12" &filte!="c18" &filte!="c24" &filte!="c30"){stop("Invalid argument: filte' has to be either 'haar', 'd4', 'd6', 'd8', 'd10', 'd12', 'd14', 'd16', 'd18', 'd20', 'la8', 'la10', 'la12', 'la14', 'la16', 'la18', 'la20', 'bl14', 'bl18', 'bl20', 'c6', 'c12', 'c18', 'c24', or 'c30'.")}
-if(class(level)!="numeric"){stop("Invalid argument: 'level' has to be of class 'numeric'.")}
-if(is.na(match(level,c(1:9)))){stop("Invalid argument: 'level' has to be between 1 and 9.")}
-slo<-10-level;
+if(class(ft)!="character"){stop("Invalid argument: 'ft' has to be of class 'character'.")}
+if(ft!="h" &ft!="d4" &ft!="d6" &ft!="d8" &ft!="d10" &ft!="d12" &ft!="d14" &ft!="d16" &ft!="d18" &ft!="d20" &ft!="la8" &ft!="la10" &ft!="la12" &ft!="la14" &ft!="la16" &ft!="la18" &ft!="la20" &ft!="bl14" &ft!="bl18" &ft!="bl20" &ft!="c6" &ft!="c12" &ft!="c18" &ft!="c24" &ft!="c30"){stop("Invalid argument: ft' has to be either 'h', 'd4', 'd6', 'd8', 'd10', 'd12', 'd14', 'd16', 'd18', 'd20', 'la8', 'la10', 'la12', 'la14', 'la16', 'la18', 'la20', 'bl14', 'bl18', 'bl20', 'c6', 'c12', 'c18', 'c24', or 'c30'.")}
+if(class(lv)!="numeric"){stop("Invalid argument: 'lv' has to be of class 'numeric'.")}
+if(is.na(match(lv,c(1:9)))){stop("Invalid argument: 'lv' has to be between 1 and 9.")}
+slo<-10-lv;
 # gmb.fit:
 if(class(distribution)!="character"){stop("Invalid argument: 'distribution' has to be of class 'character'.")}
-if(is.na(match(distribution,c("gaussian","laplace","bernoulli","adaboost","poisson","coxph")))){stop("Invalid argument: 'distribution' has to be either 'gaussian', 'laplace', 'bernoulli', 'adaboost', 'poisson' or 'coxph'.")}
-if(class(n.trees)!="numeric" & class(n.trees)!="integer"){stop("Invalid argument: 'n.trees' has to be of class 'numeric' or 'integer'.")}
-if(class(n.trees)=="numeric"){n.trees <-as.integer(n.trees)};
-if(class(shrinkage)!="numeric"){stop("Invalid argument: 'shrinkage' has to be of class 'numeric'.")}
+if(is.na(match(distribution,c("g","laplace","bernoulli","adaboost","poisson","coxph")))){stop("Invalid argument: 'distribution' has to be either 'g', 'laplace', 'bernoulli', 'adaboost', 'poisson' or 'coxph'.")}
+if(class(nt)!="numeric" & class(nt)!="integer"){stop("Invalid argument: 'nt' has to be of class 'numeric' or 'integer'.")}
+if(class(nt)=="numeric"){nt <-as.integer(nt)};
+if(class(s)!="numeric"){stop("Invalid argument: 's' has to be of class 'numeric'.")}
 # svm:
-if(class(kerne)!="character"){stop("Invalid argument: 'kerne' has to be of class 'character'.")}
-if(is.na(match(kerne,c("polynomial","linear","sigmoid","radial")))){stop("Invalid argument: 'kerne' has to be either 'polynomial', 'linear','sigmoid' or 'radial'.")}
+if(class(k)!="character"){stop("Invalid argument: 'k' has to be of class 'character'.")}
+if(is.na(match(k,c("polynomial","linear","sigmoid","ra")))){stop("Invalid argument: 'k' has to be either 'polynomial', 'linear','sigmoid' or 'ra'.")}
 
 # Spectral transformation:
 
-if(spec.type=="raw"){
+if(sp=="raw"){
 	x.tr<-x;
 	}
 	
-if(spec.type=="derivative"){
+if(sp=="derivative"){
 x.tr<-matrix(nrow=nrow(x),ncol=ncol(x),dimnames=list(rownames(x),colnames(x)));
 waveb<-as.numeric(colnames(x));
-require(KernSmooth,quietly=T);
+#require(KernSmooth,quietly=T);
 for(i in 1:nrow(x)){
 	x.tr[i,]<-locpoly(waveb,x[i,],drv=drv,bandwidth=bandwidth,gridsize=ncol(x))[[2]]
 	}
-detach(package:KernSmooth);
+#detach(package:KernSmooth);
 	}
 	
-if(spec.type=="continuum removed"){
+if(sp=="continuum removed"){
 x.tr<-matrix(nrow=nrow(x),ncol=ncol(x),dimnames=list(rownames(x),colnames(x)));
 waveb<-as.numeric(colnames(x));
-require(KernSmooth,quietly=T);	
+#require(KernSmooth,quietly=T);	
 test<-x;
 for(i in 1:nrow(x)){
 	test.1<-cbind(waveb,test[i,]);
@@ -124,10 +129,10 @@ for(i in 1:nrow(x)){
 	x.tr[i,]<-cr;
 	}
 x.tr<-x.tr[,2:(ncol(x)-2)];
-detach(package:KernSmooth);
+#detach(package:KernSmooth);
 	}
 	
-if(spec.type=="wavelet transformed"){
+if(sp=="wt"){
 waveb<-as.numeric(colnames(x));
 waveb.1024.up<-round(max(waveb));
 waveb.1024.down<-round(min(waveb));
@@ -142,13 +147,13 @@ x.comp<-matrix(nrow=nrow(x),ncol=length(waveb.1024),dimnames=list(rownames(x),wa
 for(i in 1:nrow(x)){
 	x.comp[i,]<-round(spline(waveb,x[i,],method="natural",xout=waveb.1024)[[2]],6);
 }
-require(wavelets,quietly=T);
+#require(wavelets,quietly=T);
 x.tr<-matrix(nrow=nrow(x.comp),ncol=2^slo,dimnames=list(rownames(x.comp),paste("WC_",c(1:2^slo),sep="")));
 for(i in 1:nrow(x.tr)){
-	blub<-dwt(x.comp[i,],filter=filte);
-	x.tr[i,]<-slot(blub,"W")[[level]]
+	blub<-dwt(x.comp[i,],filter=ft);
+	x.tr[i,]<-slot(blub,"W")[[lv]]
 	}
-detach(package:wavelets);
+#detach(package:wavelets);
 	}
 
 # Reference data transformation:
@@ -164,7 +169,7 @@ y.bc<-matrix(nrow=nrow(y),ncol=length(y.bc.n),dimnames=list(rownames(y),y.bc.n))
 y.sqrt<-matrix(nrow=nrow(y),ncol=length(y.sqrt.n),dimnames=list(rownames(y),y.sqrt.n));
 y.log<-matrix(nrow=nrow(y),ncol=length(y.log.n),dimnames=list(rownames(y),y.log.n));
 
-require(car,quietly=T);
+#require(car,quietly=T);
 lambda<-c();
 y.1<-y+1;
 for(i in 1:ncol(y.1)){
@@ -172,14 +177,14 @@ lambda[i]<-box.cox.powers(na.omit(y.1[,i]))[[1]];
 y.bc[,i]<-bc(y.1[,i],lambda[i]);
 	};
 y.bc<-as.data.frame(y.bc);
-detach(package:car);
+#detach(package:car);
 y.sqrt<-sqrt(y);
 y.log<-log(y+1);
 
 tr<-c("Untransformed","Box-Cox transformed","Square root transformed","Log transformed");
 tr.n<-c();
 for(i in 1:ncol(y)){
-	x11(width=8,height=8);
+	dev.new(width=8,height=8);
 	par(mfrow=c(2,2));
 	plot(density(na.omit(y[,i])),main=paste("Untransformed",y.n.n[i]));
 	plot(density(na.omit(y.bc[,i])),main=paste("Box-Cox transformed",y.n.n[i]));
@@ -343,11 +348,11 @@ for(i in 1:length(variables)){
 	}
 val.mp<-as.data.frame(val.mp);
 
-if(reg=="pls"){
+if(r=="pls"){
 
 # PLS:
 
-require(pls,quietly=T);
+#require(pls,quietly=T);
 
 model<-list();
 bc.cal<-list();
@@ -411,17 +416,17 @@ if(im[i]==4){
 	val.mp[val[[i]],paste("pred.",variables[i],sep="")]<-exp(val.mp[val[[i]],paste("pred.",colnames(y.tr)[i],sep="")])-1	}
 bc.val[[i]]<-which(val.mp[val[[i]],paste("pred.",variables[i],sep="")]=="NaN");
 }
-detach(package:pls);
+#detach(package:pls);
 	}
 
-if(reg=="brt"){
+if(r=="brt"){
 
 # GBM:
 
-require(splines,quietly=T);
-require(survival,quietly=T);
-require(lattice,quietly=T);
-require(gbm,quietly=T);
+#require(splines,quietly=T);
+#require(survival,quietly=T);
+#require(lattice,quietly=T);
+#require(gbm,quietly=T);
 
 model<-list();
 bc.cal<-list();
@@ -429,21 +434,21 @@ bc.val<-list();
 
 for(i in 1:length(variables)){
 
-cal.gbm<-gbm.fit(x.tr[cal[[i]],],cal.mp[cal[[i]],colnames(y.tr)[i]],distribution = distribution,shrinkage=shrinkage,n.trees=n.trees,verbose=FALSE);
+cal.gbm<-gbm.fit(x.tr[cal[[i]],],cal.mp[cal[[i]],colnames(y.tr)[i]],distribution = distribution,s=s,nt=nt,verbose=FALSE);
 cal.stat[variables[i],"n trees"]<-gbm.perf(cal.gbm,method="OOB",plot.it=FALSE)
 # Calculate cal-subset statistics:
 if(im[i]==1){
-	cal.mp[cal[[i]],paste("pred.",variables[i],sep="")]<-predict(cal.gbm,newdata=x.tr[cal[[i]],],n.trees=cal.stat[variables[i],"n trees"],type="response");
+	cal.mp[cal[[i]],paste("pred.",variables[i],sep="")]<-predict(cal.gbm,newdata=x.tr[cal[[i]],],nt=cal.stat[variables[i],"n trees"],type="response");
 	}
 if(im[i]==2){
-	cal.mp[cal[[i]],paste("pred.",colnames(cal.mp)[i],sep="")]<-predict(cal.gbm,newdata=x.tr[cal[[i]],],n.trees=cal.stat[variables[i],"n trees"],type="response");
+	cal.mp[cal[[i]],paste("pred.",colnames(cal.mp)[i],sep="")]<-predict(cal.gbm,newdata=x.tr[cal[[i]],],nt=cal.stat[variables[i],"n trees"],type="response");
 	cal.mp[cal[[i]],paste("pred.",variables[i],sep="")]<-(cal.mp[cal[[i]],paste("pred.",colnames(cal.mp)[i],sep="")]*lambda[variables[i]]+1)^(1/lambda[variables[i]])-1;
 	}
 if(im[i]==3){
-	cal.mp[cal[[i]],paste("pred.",colnames(cal.mp)[i],sep="")]<-predict(cal.gbm,newdata=x.tr[cal[[i]],],n.trees=cal.stat[variables[i],"n trees"],type="response");
+	cal.mp[cal[[i]],paste("pred.",colnames(cal.mp)[i],sep="")]<-predict(cal.gbm,newdata=x.tr[cal[[i]],],nt=cal.stat[variables[i],"n trees"],type="response");
 	cal.mp[cal[[i]],paste("pred.",variables[i],sep="")]<-cal.mp[cal[[i]],paste("pred.",colnames(cal.mp)[i],sep="")]^2	}
 if(im[i]==4){
-	cal.mp[cal[[i]],paste("pred.",colnames(cal.mp)[i],sep="")]<-predict(cal.gbm,newdata=x.tr[cal[[i]],],n.trees=cal.stat[variables[i],"n trees"],type="response");
+	cal.mp[cal[[i]],paste("pred.",colnames(cal.mp)[i],sep="")]<-predict(cal.gbm,newdata=x.tr[cal[[i]],],nt=cal.stat[variables[i],"n trees"],type="response");
 	cal.mp[cal[[i]],paste("pred.",variables[i],sep="")]<-exp(cal.mp[cal[[i]],paste("pred.",colnames(cal.mp)[i],sep="")])-1	}
 bc.cal[[i]]<-which(cal.mp[cal[[i]],paste("pred.",variables[i],sep="")]=="NaN");
 
@@ -451,29 +456,29 @@ model[[i]]<-cal.gbm
 model[[i]]$constituent<-variables[i];
 # Calculate val-subset statistics:
 if(im[i]==1){
-	val.mp[val[[i]],paste("pred.",variables[i],sep="")]<-predict(cal.gbm,newdata=x.tr[val[[i]],],n.trees=cal.stat[variables[i],"n trees"],type="response");
+	val.mp[val[[i]],paste("pred.",variables[i],sep="")]<-predict(cal.gbm,newdata=x.tr[val[[i]],],nt=cal.stat[variables[i],"n trees"],type="response");
 	}
 if(im[i]==2){
-	val.mp[val[[i]],paste("pred.",colnames(cal.mp)[i],sep="")]<-predict(cal.gbm,newdata=x.tr[val[[i]],],n.trees=cal.stat[variables[i],"n trees"],type="response");
+	val.mp[val[[i]],paste("pred.",colnames(cal.mp)[i],sep="")]<-predict(cal.gbm,newdata=x.tr[val[[i]],],nt=cal.stat[variables[i],"n trees"],type="response");
 	val.mp[val[[i]],paste("pred.",variables[i],sep="")]<-(val.mp[val[[i]],paste("pred.",colnames(cal.mp)[i],sep="")]*lambda[variables[i]]+1)^(1/lambda[variables[i]])-1;
 	}
 if(im[i]==3){
-	val.mp[val[[i]],paste("pred.",colnames(cal.mp)[i],sep="")]<-predict(cal.gbm,newdata=x.tr[val[[i]],],n.trees=cal.stat[variables[i],"n trees"],type="response");
+	val.mp[val[[i]],paste("pred.",colnames(cal.mp)[i],sep="")]<-predict(cal.gbm,newdata=x.tr[val[[i]],],nt=cal.stat[variables[i],"n trees"],type="response");
 	val.mp[val[[i]],paste("pred.",variables[i],sep="")]<-val.mp[val[[i]],paste("pred.",colnames(cal.mp)[i],sep="")]^2	}
 if(im[i]==4){
-	val.mp[val[[i]],paste("pred.",colnames(cal.mp)[i],sep="")]<-predict(cal.gbm,newdata=x.tr[val[[i]],],n.trees=cal.stat[variables[i],"n trees"],type="response");
+	val.mp[val[[i]],paste("pred.",colnames(cal.mp)[i],sep="")]<-predict(cal.gbm,newdata=x.tr[val[[i]],],nt=cal.stat[variables[i],"n trees"],type="response");
 	val.mp[val[[i]],paste("pred.",variables[i],sep="")]<-exp(val.mp[val[[i]],paste("pred.",colnames(cal.mp)[i],sep="")])-1	}
 bc.val[[i]]<-which(val.mp[val[[i]],paste("pred.",variables[i],sep="")]=="NaN");
 }
-detach(package:gbm);
-detach(package:splines);
-detach(package:survival);
-detach(package:lattice);
+#detach(package:gbm);
+#detach(package:splines);
+#detach(package:survival);
+#detach(package:lattice);
 	}
 	
-if(reg=="svm"){
-require(class,quietly=T);
-require(e1071,quietly=T);
+if(r=="svm"){
+#require(class,quietly=T);
+#require(e1071,quietly=T);
 
 model<-list();
 bc.cal<-list();
@@ -481,12 +486,12 @@ bc.val<-list();
 
 for(i in 1:length(variables)){
 
-test<-tune.svm(type="eps",kernel=kerne,x.tr[cal[[i]],],cal.mp[cal[[i]],colnames(y.tr)[i]],cost=c(2,3,4,5,6),epsilon=c(0.05,0.1,0.2),gamma=c(0.01,0.001,0.0001,0.00001),tunecontrol=tune.control(sampling="fix",fix=0.7));
-test<-tune.svm(type="eps",kernel=kerne,x.tr[cal[[i]],],cal.mp[cal[[i]],colnames(y.tr)[i]],cost=test[[1]][2][1,1],epsilon=test[[1]][3][1,1],gamma=c(test[[1]][1][1,1]-test[[1]][1][1,1]*0.6,test[[1]][1][1,1]-test[[1]][1][1,1]*0.4,test[[1]][1][1,1]-test[[1]][1][1,1]*0.2,test[[1]][1][1,1],test[[1]][1][1,1]+test[[1]][1][1,1]*2,test[[1]][1][1,1]+test[[1]][1][1,1]*4,test[[1]][1][1,1]+test[[1]][1][1,1]*6),tunecontrol=tune.control(sampling="fix",fix=0.7));
+test<-tune.svm(type="eps",kernel=k,x.tr[cal[[i]],],cal.mp[cal[[i]],colnames(y.tr)[i]],cost=c(2,3,4,5,6),epsilon=c(0.05,0.1,0.2),gamma=c(0.01,0.001,0.0001,0.00001),tunecontrol=tune.control(sampling="fix",fix=0.7));
+test<-tune.svm(type="eps",kernel=k,x.tr[cal[[i]],],cal.mp[cal[[i]],colnames(y.tr)[i]],cost=test[[1]][2][1,1],epsilon=test[[1]][3][1,1],gamma=c(test[[1]][1][1,1]-test[[1]][1][1,1]*0.6,test[[1]][1][1,1]-test[[1]][1][1,1]*0.4,test[[1]][1][1,1]-test[[1]][1][1,1]*0.2,test[[1]][1][1,1],test[[1]][1][1,1]+test[[1]][1][1,1]*2,test[[1]][1][1,1]+test[[1]][1][1,1]*4,test[[1]][1][1,1]+test[[1]][1][1,1]*6),tunecontrol=tune.control(sampling="fix",fix=0.7));
 c<-test[[1]][2][1,1];
 e<-test[[1]][3][1,1];
 g<-test[[1]][1][1,1];
-cal.svm<-svm(x.tr[cal[[i]],],cal.mp[cal[[i]],colnames(y.tr)[i]],type="eps",kernel=kerne,cost=c,epsilon=e,gamma=g);
+cal.svm<-svm(x.tr[cal[[i]],],cal.mp[cal[[i]],colnames(y.tr)[i]],type="eps",kernel=k,cost=c,epsilon=e,gamma=g);
 # Calculate cal-subset statistics:
 if(im[i]==1){
 	cal.mp[cal[[i]],paste("pred.",variables[i],sep="")]<-predict(cal.svm,newdata=x.tr[cal[[i]],]);
@@ -520,8 +525,8 @@ if(im[i]==4){
 	val.mp[val[[i]],paste("pred.",variables[i],sep="")]<-exp(val.mp[val[[i]],paste("pred.",colnames(y.tr)[i],sep="")])-1	}
 bc.val[[i]]<-which(val.mp[val[[i]],paste("pred.",variables[i],sep="")]=="NaN");
 }
-detach(package:e1071);
-detach(package:class);
+#detach(package:e1071);
+#detach(package:class);
 	}
 
 # Compute statistics independend of regression method:
@@ -652,7 +657,7 @@ rmsep.1[j]<-round(sqrt(median((val.mp[p[b.1],paste("pred.",variables[i],sep="")]
 
 # Plot linear regression of measured against predicted of calibration and validation sets:
 
-x11(width=5,height=2.5*length(variables));
+dev.new(width=5,height=2.5*length(variables));
 par(mfrow=c(length(variables),2));
 for(i in 1:length(variables)){
 mi<-min(na.omit(c(cal.mp[,variables[i]],cal.mp[,paste("pred.",variables[i],sep="")],val.mp[,variables[i]],val.mp[,paste("pred.",variables[i],sep="")])));
@@ -669,12 +674,12 @@ print(val.stat);
 
 # Prepare output:
 
-output<-list("model.name"=model.name,"model"=model,"x.tr"=x.tr,"spectral.transformation"=spec.type,"constituents"=variables,"constituents.transformation"=tr.n,"lambda"=lambda,"method"=reg,"cal.samples"=cal,"val.samples"=val,"cal.statistics"=cal.stat,"cal.mea.pre"=cal.mp,"val.statistics"=val.stat,"val.mea.pre"=val.mp,"cal.pca"=pca.l,"mahalanobis"=mah.l,"cal.range"=ran,"rmsep"=rmsep.l,"lm"=lm.l,"wavebands"=waveb,"drv"=drv,"bandwidth"=bandwidth,"filter"=filte,"level"=level);
+output<-list("model"=model,"model"=model,"x.tr"=x.tr,"spectral.transformation"=sp,"constituents"=variables,"constituents.transformation"=tr.n,"lambda"=lambda,"method"=r,"cal.samples"=cal,"val.samples"=val,"cal.statistics"=cal.stat,"cal.mea.pre"=cal.mp,"val.statistics"=val.stat,"val.mea.pre"=val.mp,"cal.pca"=pca.l,"mahalanobis"=mah.l,"cal.range"=ran,"rmsep"=rmsep.l,"lm"=lm.l,"wavebands"=waveb,"drv"=drv,"bandwidth"=bandwidth,"filter"=ft,"lv"=lv);
 class(output)<-"regr";
-if(sav!="NULL"){
-		setwd(sav);
+if(sw!="NL"){
+		setwd(sw);
 		}
-save(output,file=model.name)
+save(output,file=model)
 return(output);
 
 	}
